@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2001 Peter Miller;
+ *	Copyright (C) 1998, 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -103,4 +103,14 @@ size_t wcsrtombs _((char *, const wchar_t **, size_t, mbstate_t *));
 
 #endif /* !HAVE_ISWPRINT */
 
+/*
+ * The ANSI C standard states that wint_t symbol shall be defined by
+ * <wchar.h> and <wctype.h>.  The GNU people also define it in <stddef.h>,
+ * but this is incorrect.
+ */
+#ifndef HAVE_WINT_T
+#define HAVE_WINT_T
+typedef wchar_t wint_t;
+#endif
+
 #endif /* COMMON_AC_WCHAR_H */
