@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998, 2000, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -77,8 +77,8 @@ arglex_compare(formal, actual)
 	for (;;)
 	{
 		ac = *actual++;
-		if (isupper(ac))
-			ac = tolower(ac);
+		if (isupper((unsigned char)ac))
+			ac = tolower((unsigned char)ac);
 		fc = *formal++;
 		switch (fc)
 		{
@@ -109,7 +109,7 @@ arglex_compare(formal, actual)
 			 * skip forward to next
 			 * mandatory character, or after '_'
 			 */
-			while (islower(*formal))
+			while (islower((unsigned char)*formal))
 				++formal;
 			if (*formal == '_')
 			{
@@ -149,7 +149,7 @@ arglex_compare(formal, actual)
 		case 'P': case 'Q': case 'R': case 'S': case 'T':
 		case 'U': case 'V': case 'W': case 'X': case 'Y':
 		case 'Z': 
-			fc = tolower(fc);
+			fc = tolower((unsigned char)fc);
 			/* fall through... */
 
 		default:
