@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998, 2000, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -70,7 +70,7 @@ struct chunk
 #define	CHUNKSIZE(size) (sizeof(CHUNK) + (size) - sizeof(double))
 
 #define	DPTOCP(dp) \
-	((CHUNK *) (((char *)(dp)) - offsetof(CHUNK, data[0])))
+	((CHUNK *)(void*)(((char *)(dp)) - offsetof(CHUNK, data[0])))
 
 
 static	CHUNK	head = {&head, &head};
