@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1995, 1998-2001 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -41,6 +41,7 @@
  */
 
 #include <ac/ctype.h>
+#include <ac/stddef.h>
 #include <ac/stdio.h>
 #include <ac/string.h>
 #include <ac/libintl.h>
@@ -227,13 +228,26 @@ canonical(s)
  * strings cannot be freed or realloced.
  */
 
-char *
+void *
 allocstr(len)
 	long	len;
 {
 	char	*cp;
+	static unsigned alignment_mask;
+
+	if (!alignment_mask)
+	{
+		struct test { char a; double b; };
+		unsigned alignment = offsetof(struct test, b);
+		/* make sure is a power of 2 */
+		while ((alignment & (~alignment + 1)) != alignment)
+			++alignment;
+		alignment_mask = alignment - 1;
+	}
+
+	/* round length to a multiple of alignment */
+	len = (len + alignment_mask) & ~alignment_mask;
 
-	len = (len + 3) & ~3;		/* round to multiple of 4 */
 	if (len >= UNIQUEALLOCSIZE)
 		return cm_alloc_and_check(len);
 	cp = nextchar;
