@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2001 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -140,7 +140,7 @@ struct INFO;
 /*
  * Function prototypes
  */
-char *allocstr _((long));
+void *allocstr _((long));
 void fcomp _((char *fileA, char *fileB));
 void dumpmatch _((char *outfile));
 void dumpnormal _((char *outfile));
