@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -633,7 +633,7 @@ str_bool(s)
 	cp = s->str_text;
 	while (*cp)
 	{
-		if (!isspace(*cp) && *cp != '0')
+		if (!isspace((unsigned char)*cp) && *cp != '0')
 			return 1;
 		++cp;
 	}
