@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2001 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -115,6 +115,7 @@ enum
 	arglex_token_update,
 	arglex_token_verbose,
 	arglex_token_what,
+	arglex_token_keywords_not,
 };
 
 static arglex_table_ty argtab[] =
@@ -136,6 +137,7 @@ static arglex_table_ty argtab[] =
 	{ "-MaKe_Path",		arglex_token_make_path,			},
 	{ "-Modify",		arglex_token_modified,			},
 	{ "-Name",		arglex_token_nname,			},
+	{ "-No_Keywords",	arglex_token_keywords_not,		},
 	{ "-No_Write",		arglex_token_no_write,			},
 	{ "-Output",		arglex_token_output,			},
 	{ "-PRune",		arglex_token_prune,			},
@@ -867,6 +869,10 @@ main(argc, argv)
 		case arglex_token_binary:
 			fc.binary = 1;
 			break;
+
+		case arglex_token_keywords_not:
+			sc.modifylines = 0;
+			break;
 		}
 		arglex();
 	}
