@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2001 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -162,7 +162,7 @@ findeditnumber(fp, editname)
 	 * of the name and skip over it to where a number can start.
 	 */
 	endname = 0;
-	if ((*cp != '-') && (*cp != '+') && !isdigit(*cp))
+	if ((*cp != '-') && (*cp != '+') && !isdigit((unsigned char)*cp))
 	{
 		name = cp;
 		while (*cp && (*cp != '-') && (*cp != '+'))
@@ -174,7 +174,7 @@ findeditnumber(fp, editname)
 	 */
 	if ((*cp == '+') || (*cp == '-'))
 		isneg = (*cp++ == '-');
-	while (isdigit(*cp))
+	while (isdigit((unsigned char)*cp))
 		reledit = reledit * 10 + (*cp++ - '0');
 	if (*cp || (reledit < 0))
 	{
@@ -249,10 +249,10 @@ findeditnumber(fp, editname)
 			 */
 			while (*cp)
 			{
-				while (isspace(*cp))
+				while (isspace((unsigned char)*cp))
 					cp++;
 				testname = cp;
-				while (*cp && !isspace(*cp))
+				while (*cp && !isspace((unsigned char)*cp))
 					cp++;
 				*cp++ = '\0';
 				if ((*testname == *name) && (strcmp(testname, name) == 0))
@@ -674,12 +674,12 @@ getnumber(cp, value)
 	nonum = 1;
 	isneg = 0;
 	*value = 0;
-	while (isspace(*cp))
+	while (isspace((unsigned char)*cp))
 		cp++;
 	isneg = (*cp == '-');
 	if (isneg)
 		cp++;
-	while (isdigit(*cp))
+	while (isdigit((unsigned char)*cp))
 	{
 		*value = (*value * 10) + *cp++ - '0';
 		if (*value < 0)
@@ -688,7 +688,7 @@ getnumber(cp, value)
 	}
 	if (isneg)
 		*value = -*value;
-	if (nonum || (*cp && !isspace(*cp)))
+	if (nonum || (*cp && !isspace((unsigned char)*cp)))
 		cp = NULL;
 	return cp;
 }
